@@ -4,13 +4,7 @@
 <!--BEGIN STABILITY BANNER-->---
 
 
-![cdk-constructs: Experimental](https://img.shields.io/badge/cdk--constructs-experimental-important.svg?style=for-the-badge)
-
-> The APIs of higher level constructs in this module are experimental and under active development.
-> They are subject to non-backward compatible changes or removal in any future version. These are
-> not subject to the [Semantic Versioning](https://semver.org/) model and breaking changes will be
-> announced in the release notes. This means that while you may use them, you may need to update
-> your source code when upgrading to a newer version of this package.
+![cdk-constructs: Stable](https://img.shields.io/badge/cdk--constructs-stable-success.svg?style=for-the-badge)
 
 ---
 <!--END STABILITY BANNER-->
@@ -52,8 +46,6 @@ class Alarms:
         '''
         :param lower_alarm_interval_index: 
         :param upper_alarm_interval_index: 
-
-        :stability: experimental
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if lower_alarm_interval_index is not None:
@@ -63,17 +55,11 @@ class Alarms:
 
     @builtins.property
     def lower_alarm_interval_index(self) -> typing.Optional[jsii.Number]:
-        '''
-        :stability: experimental
-        '''
         result = self._values.get("lower_alarm_interval_index")
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
     def upper_alarm_interval_index(self) -> typing.Optional[jsii.Number]:
-        '''
-        :stability: experimental
-        '''
         result = self._values.get("upper_alarm_interval_index")
         return typing.cast(typing.Optional[jsii.Number], result)
 
@@ -104,8 +90,6 @@ class ArbitraryIntervals:
         '''
         :param absolute: 
         :param intervals: 
-
-        :stability: experimental
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "absolute": absolute,
@@ -114,18 +98,12 @@ class ArbitraryIntervals:
 
     @builtins.property
     def absolute(self) -> builtins.bool:
-        '''
-        :stability: experimental
-        '''
         result = self._values.get("absolute")
         assert result is not None, "Required property 'absolute' is missing"
         return typing.cast(builtins.bool, result)
 
     @builtins.property
     def intervals(self) -> typing.List["ScalingInterval"]:
-        '''
-        :stability: experimental
-        '''
         result = self._values.get("intervals")
         assert result is not None, "Required property 'intervals' is missing"
         return typing.cast(typing.List["ScalingInterval"], result)
@@ -159,8 +137,6 @@ class CompleteScalingInterval:
         :param lower: 
         :param upper: 
         :param change: 
-
-        :stability: experimental
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "lower": lower,
@@ -171,27 +147,18 @@ class CompleteScalingInterval:
 
     @builtins.property
     def lower(self) -> jsii.Number:
-        '''
-        :stability: experimental
-        '''
         result = self._values.get("lower")
         assert result is not None, "Required property 'lower' is missing"
         return typing.cast(jsii.Number, result)
 
     @builtins.property
     def upper(self) -> jsii.Number:
-        '''
-        :stability: experimental
-        '''
         result = self._values.get("upper")
         assert result is not None, "Required property 'upper' is missing"
         return typing.cast(jsii.Number, result)
 
     @builtins.property
     def change(self) -> typing.Optional[jsii.Number]:
-        '''
-        :stability: experimental
-        '''
         result = self._values.get("change")
         return typing.cast(typing.Optional[jsii.Number], result)
 
@@ -209,19 +176,12 @@ class CompleteScalingInterval:
 
 @jsii.interface(jsii_type="@aws-cdk/aws-autoscaling-common.IRandomGenerator")
 class IRandomGenerator(typing_extensions.Protocol):
-    '''
-    :stability: experimental
-    '''
-
     @builtins.staticmethod
     def __jsii_proxy_class__() -> typing.Type["_IRandomGeneratorProxy"]:
         return _IRandomGeneratorProxy
 
     @jsii.member(jsii_name="nextBoolean")
     def next_boolean(self) -> builtins.bool:
-        '''
-        :stability: experimental
-        '''
         ...
 
     @jsii.member(jsii_name="nextInt")
@@ -229,24 +189,15 @@ class IRandomGenerator(typing_extensions.Protocol):
         '''
         :param min: -
         :param max: -
-
-        :stability: experimental
         '''
         ...
 
 
 class _IRandomGeneratorProxy:
-    '''
-    :stability: experimental
-    '''
-
     __jsii_type__: typing.ClassVar[str] = "@aws-cdk/aws-autoscaling-common.IRandomGenerator"
 
     @jsii.member(jsii_name="nextBoolean")
     def next_boolean(self) -> builtins.bool:
-        '''
-        :stability: experimental
-        '''
         return typing.cast(builtins.bool, jsii.invoke(self, "nextBoolean", []))
 
     @jsii.member(jsii_name="nextInt")
@@ -254,8 +205,6 @@ class _IRandomGeneratorProxy:
         '''
         :param min: -
         :param max: -
-
-        :stability: experimental
         '''
         return typing.cast(jsii.Number, jsii.invoke(self, "nextInt", [min, max]))
 
@@ -273,13 +222,11 @@ class ScalingInterval:
         lower: typing.Optional[jsii.Number] = None,
         upper: typing.Optional[jsii.Number] = None,
     ) -> None:
-        '''(experimental) A range of metric values in which to apply a certain scaling operation.
+        '''A range of metric values in which to apply a certain scaling operation.
 
-        :param change: (experimental) The capacity adjustment to apply in this interval. The number is interpreted differently based on AdjustmentType: - ChangeInCapacity: add the adjustment to the current capacity. The number can be positive or negative. - PercentChangeInCapacity: add or remove the given percentage of the current capacity to itself. The number can be in the range [-100..100]. - ExactCapacity: set the capacity to this number. The number must be positive.
-        :param lower: (experimental) The lower bound of the interval. The scaling adjustment will be applied if the metric is higher than this value. Default: Threshold automatically derived from neighbouring intervals
-        :param upper: (experimental) The upper bound of the interval. The scaling adjustment will be applied if the metric is lower than this value. Default: Threshold automatically derived from neighbouring intervals
-
-        :stability: experimental
+        :param change: The capacity adjustment to apply in this interval. The number is interpreted differently based on AdjustmentType: - ChangeInCapacity: add the adjustment to the current capacity. The number can be positive or negative. - PercentChangeInCapacity: add or remove the given percentage of the current capacity to itself. The number can be in the range [-100..100]. - ExactCapacity: set the capacity to this number. The number must be positive.
+        :param lower: The lower bound of the interval. The scaling adjustment will be applied if the metric is higher than this value. Default: Threshold automatically derived from neighbouring intervals
+        :param upper: The upper bound of the interval. The scaling adjustment will be applied if the metric is lower than this value. Default: Threshold automatically derived from neighbouring intervals
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "change": change,
@@ -291,7 +238,7 @@ class ScalingInterval:
 
     @builtins.property
     def change(self) -> jsii.Number:
-        '''(experimental) The capacity adjustment to apply in this interval.
+        '''The capacity adjustment to apply in this interval.
 
         The number is interpreted differently based on AdjustmentType:
 
@@ -301,8 +248,6 @@ class ScalingInterval:
           capacity to itself. The number can be in the range [-100..100].
         - ExactCapacity: set the capacity to this number. The number must
           be positive.
-
-        :stability: experimental
         '''
         result = self._values.get("change")
         assert result is not None, "Required property 'change' is missing"
@@ -310,26 +255,22 @@ class ScalingInterval:
 
     @builtins.property
     def lower(self) -> typing.Optional[jsii.Number]:
-        '''(experimental) The lower bound of the interval.
+        '''The lower bound of the interval.
 
         The scaling adjustment will be applied if the metric is higher than this value.
 
         :default: Threshold automatically derived from neighbouring intervals
-
-        :stability: experimental
         '''
         result = self._values.get("lower")
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
     def upper(self) -> typing.Optional[jsii.Number]:
-        '''(experimental) The upper bound of the interval.
+        '''The upper bound of the interval.
 
         The scaling adjustment will be applied if the metric is lower than this value.
 
         :default: Threshold automatically derived from neighbouring intervals
-
-        :stability: experimental
         '''
         result = self._values.get("upper")
         return typing.cast(typing.Optional[jsii.Number], result)
